Learn R Programming

kDGLM (version 1.2.0)

gastroBR: Hospital admissions from gastroenteritis in Brazil

Description

A dataset containing the number of Hospital admissions from gastroenteritis in Brazil, per state, from 2010 to 2022 by month.

Usage

gastroBR

Arguments

Format

A data frame with 4212 rows and 4 variables:

UF

The abbreviated state name.

Date

The date of the observation. Note that the day is only a placeholder and is just a placeholder.

Admissions

The number hospital admissions.

Population

The estimated population.