Integer: The index of the variables from which to set the prior.
a1
Numeric: The prior mean.
R1
Matrix: The prior covariance matrix.
Details
The discount factor must be the same for all variables whose prior is being modified.
For the details about the implementation see ArtigoPacote;textualkDGLM.
References
See Also
Other auxiliary functions for defining priors.:
CAR_prior(),
zero_sum_prior()